@@ -14,6 +14,7 @@ class Plot:
         self.title = title
         self.points = []
         self.lines = []
+        self.rects = []
         self.late_vertexors = []
         self.texts = []
         self.x_min =  math.inf
@@ -37,8 +38,16 @@ class Plot:
         self._include(xi, yi)
         self._include(xf, yf)
 
-    def late_vertexor(self, vertexor):
+    def rect(self, xi, yi, xf, yf, r=255, g=255, b=255, a=255):
+        yi = -yi
+        yf = -yf
+        self.rects.append([xi, yi, xf, yf, r, g, b, a])
+        self._include(xi, yi)
+        self._include(xf, yf)
+
+    def late_vertexor(self, vertexor, x, y):
         self.late_vertexors.append(vertexor)
+        self._include(x, -y)
 
     def text(self, s, x, y, r=255, g=255, b=255, a=255):
         y = -y
